==> kubernetes-model-apps-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apps/DaemonSetUpdateStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DaemonSetUpdateStrategyFluent<A extends io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet getRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet buildRollingUpdate();
  public A withRollingUpdate(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet rollingUpdate);
  public java.lang.Boolean hasRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet item);
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public interface RollingUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent<io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<N>>{
    public N and();
    public N endRollingUpdate();
    
  }
  
}

==> kubernetes-model-apps-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apps/DaemonSetUpdateStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DaemonSetUpdateStrategyFluent<A extends io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet getRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet buildRollingUpdate();
  public A withRollingUpdate(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet rollingUpdate);
  public java.lang.Boolean hasRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet item);
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
  public io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSet item);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface RollingUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apps.RollingUpdateDaemonSetFluent<io.fabric8.kubernetes.api.model.apps.DaemonSetUpdateStrategyFluent.RollingUpdateNested<N>>{
    public N and();
    public N endRollingUpdate();
    
  }
  
}
